<?php

namespace Teknisa\SM\Factory;

class IntegracaoPmFactory {
    
    protected $connection;
    
    public function __construct($connection) {
        $this->connection = $connection;
    }
    
    public function getDadosModeloPropostaCustomizacao(array $params) {
        $sql = "SELECT NRORCAMENTOMODELO,
                       IDFATURACONTR,
                       CDMODPGTO,
                       NRGRUPOFATURA,
                       QTDIASVALIDADE,
                       QTDIASCONTRATO
                  FROM FCT_ORCAMENTOMODELO
                 WHERE NRORG             = :NRORG
                   AND IDATIVO           = 'S'
                   AND NRORCAMENTOMODELO = (SELECT NRORCAMODELOCUST
                                              FROM FCT_PARAMETROGERAL
                                             WHERE NRORG = FCT_ORCAMENTOMODELO.NRORG)";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getCodigoInterlocutor(array $params) {
        $sql = "SELECT NRSEQINTERLOCUTOR
                  FROM CRM_INTERLOCUTOR
                 WHERE (EMAILINTERLOC        = :EMAILINTERLOC
                    OR UPPER(NMINTERLOCUTOR) = UPPER(:NMINTERLOCUTOR))
                   AND NRORG                 = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getNrparcnegocioCliente(array $params) {
        $sql = "SELECT NRPARCNEGOCIO
                  FROM CLIENTE
                 WHERE CDCLIENTE = :CDCLIENTE
                   AND NRORG     = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getEscoposModeloProposta(array $params) {
        $sql = "SELECT NRRELACESCOPOMODELO,
                       NRTIPOORCAMENTO,
                       CDFILIAL
                  FROM FCT_RELACESCOPOMODELO
                 WHERE NRORCAMENTOMODELO = :NRORCAMENTOMODELO
                   AND NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function inserirProposta(array $params) {
        $sql = "INSERT INTO FCT_ORCAMENTO (
                    NRSEQORCAMENTO       , NRPARCNEGOCIO     , NRVERSAOORCAMENTO  ,
                    NRPARCTRANSPORTADORA , DTREFORCAMENTO    , CDPRECBASESERV     ,
                    CDREDUCONT           , IDFATURAORCA      , CDMODPGTO          ,
                    NRPARCINTERLOCUTOR   , NRGRUPOFATURA     , DSREFERENCIAORCA   ,
                    IDTRANSPORTADORA     , QTDIASVALIDADE    , DTVALIDADE         ,
                    QTDIASCONTRATO       , DSEMAIL           , NMPARCINTERLOCUTOR ,
                    NRTELEFONE           , DSOBSERVACAOORCA  , IDGERACONTRATO     ,
                    IDSITUACAOORCAMENTO  , VRORCAMENTO       , NRORG              ,
                    IDATIVO              , DTINCLUSAO        , NRORGINCLUSAO      ,
                    CDOPERINCLUSAO       , DSINTERORCA       , NRORCAMENTOMODELO  ,
                    DTACEITEORCA         , NRSEQINTERLOCUTOR , CDOPERRESPONSAVEL  ,
                    IDPRODUTO            , ISSUEID           , IDASSELETRDIGITAL  
                )
                VALUES (
                    :NRSEQORCAMENTO       , :NRPARCNEGOCIO     , :NRVERSAOORCAMENTO  ,
                    :NRPARCTRANSPORTADORA , :DTREFORCAMENTO    , :CDPRECBASESERV     ,
                    :CDREDUCONT           , :IDFATURAORCA      , :CDMODPGTO          ,
                    :NRPARCINTERLOCUTOR   , :NRGRUPOFATURA     , :DSREFERENCIAORCA   ,
                    :IDTRANSPORTADORA     , :QTDIASVALIDADE    , :DTVALIDADE         ,
                    :QTDIASCONTRATO       , :DSEMAIL           , :NMPARCINTERLOCUTOR ,
                    :NRTELEFONE           , :DSOBSERVACAOORCA  , :IDGERACONTRATO     ,
                    :IDSITUACAOORCAMENTO  , :VRORCAMENTO       , :NRORG              ,
                    :IDATIVO              , SYSDATE            , :NRORGINCLUSAO      ,
                    :CDOPERINCLUSAO       , :DSINTERORCA       , :NRORCAMENTOMODELO  ,
                    :DTACEITEORCA         , :NRSEQINTERLOCUTOR , :CDOPERRESPONSAVEL  ,
                    :IDPRODUTO            , :ISSUEID           , :IDASSELETRDIGITAL
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirEscopoProposta(array $params) {
        $sql = "INSERT INTO FCT_RELACESCOPOPROPOSTA (
                    NRRELACESCOPOPROPOSTA , NRSEQORCAMENTO , NRTIPOORCAMENTO ,
                    NRSEQMODDOCFCT        , CDFILIAL       , NRORG           ,
                    IDATIVO               , DTINCLUSAO     , NRORGINCLUSAO   ,
                    CDOPERINCLUSAO
                )
                VALUES (
                    :NRRELACESCOPOPROPOSTA , :NRSEQORCAMENTO , :NRTIPOORCAMENTO ,
                    :NRSEQMODDOCFCT        , :CDFILIAL       , :NRORG           ,
                    :IDATIVO               , SYSDATE         , :NRORGINCLUSAO   ,
                    :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getDocumentosEscoposModeloProposta(array $params) {
        $sql = "SELECT REL.NRTIPOORCAMENTO,
                       DOC.NRSEQMODDOCFCT,
                       DOC.IDSITUACAOORCAMENTO,
                       MODELO.DSMODELODOCORCA,
                       MODELO.NRORDENACAO,
                       MODELO.IDIDIOMA,
                       MODELO.IDTIPOMODELODOC,
                       MODELO.TXMODELODOCORCA,
                       MODELO.NMARQUIVO,
                       MODELO.DSCAMINHOARQ,
                       MODELO.DSTIPO,
                       MODELO.VRTAMANHO
                  FROM FCT_RELACESCOPOMODELO REL
                 INNER JOIN FCT_ORCAESCOPODOC DOC
                    ON REL.NRRELACESCOPOMODELO = DOC.NRRELACESCOPOMODELO
                   AND REL.NRORG               = DOC.NRORG
                 INNER JOIN FCT_MODELODOC MODELO
                    ON DOC.NRSEQMODDOCFCT = MODELO.NRSEQMODDOCFCT
                   AND DOC.NRORG          = MODELO.NRORG
                 WHERE REL.NRORCAMENTOMODELO = :NRORCAMENTOMODELO
                   AND REL.NRORG             = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function inserirDocumentosProposta(array $params) {
        $sql = "INSERT INTO FCT_ORCAMENTODOC (
                    NRSEQORCADOC         , NRSEQORCAMENTO   , NRSEQMODDOCFCT   ,
                    IDIDIOMA             , TXMODELOORCADOC  , IDPADRAOORCADOC  ,
                    NRORG                , IDATIVO          , DTINCLUSAO       ,
                    NRORGINCLUSAO        , CDOPERINCLUSAO   , NMARQUIVO        ,
                    DSCAMINHOARQ         , DSTIPO           , VRTAMANHO        ,
                    IDSITUACAOORCAMENTO  , NRTIPOORCAMENTO
                )
                VALUES (
                    :NRSEQORCADOC        , :NRSEQORCAMENTO  , :NRSEQMODDOCFCT  ,
                    :IDIDIOMA            , :TXMODELOORCADOC , :IDPADRAOORCADOC ,
                    :NRORG               , :IDATIVO         , SYSDATE          ,
                    :NRORGINCLUSAO       , :CDOPERINCLUSAO  , :NMARQUIVO       ,
                    :DSCAMINHOARQ        , :DSTIPO          , :VRTAMANHO       ,
                    :IDSITUACAOORCAMENTO , :NRTIPOORCAMENTO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getNomeServicos($codServicos, $nrorg) {
        $sql = "SELECT CDSERVORCA, NMSERVORCA
                  FROM FCT_SERVICOORCA
                 WHERE CDSERVORCA IN (".$codServicos.")
                   AND NRORG       = :NRORG";
        
        $params = array("NRORG" => $nrorg);
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /*public function getParamsFaturamentoEscopo(array $params) {
        $sql = "SELECT NRGRUPOFATURA,
                       IDFATURACONTR,
                       CDMODPGTO,
                       QTPARCELASFATU,
                       NRDIAVENCPARCELASFATU
                  FROM FCT_PARAMFATESCOPO
                 WHERE NRTIPOORCAMENTO = :NRTIPOORCAMENTO
                   AND NRORG           = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }*/
    
    public function inserirItensProposta(array $params) {
        $sql = "INSERT INTO FCT_ITEMORCAMENTO (
                    NRITEMORCAMENTO        , NRSEQORCAMENTO     , CDSERVORCA         ,
                    NRITEMORCAMENTOPAI     , NMITEMORCAMENTO    , QTITEMORCAMENTO    ,
                    CDTPMEDIDASERV         , QTMEDIDAORCA       , NRGRUPOFATURA      ,
                    IDFATURAORCA           , CDMODPGTO          , QTPARCELASFATU     ,
                    NRDIAVENCPARCELASFATU  , DTINICFATORC       , VRUNITITEMORCA     ,
                    VRUNITITEMORCALOCA     , VRTOTALITEMORCA    , TXFORMULAITORCA    ,
                    IDTRANSPORTADORA       , QTDIASCONTRATO     , IDITEMOBRIGORCA    ,
                    IDSOMASUBITENS         , IDSOMANOITEMPAI    , IDSOMANOTOTALORCA  ,
                    IDIMPRESSAOORCA        , IDPRECOLOCACAO     , NRORG              ,
                    IDATIVO                , DTINCLUSAO         , NRORGINCLUSAO      ,
                    CDOPERINCLUSAO         , IDMULTMEDVRTOT     , IDBLOQALTORC       ,
                    IDADICITEMORC          , IDADICCOBRITEMORC  , VRITEMSEMDESC      ,
                    VRPERCDESCORCA         , IDTPDESCORCA       , NRTIPOORCAMENTO
                )
                VALUES (
                    :NRITEMORCAMENTO       , :NRSEQORCAMENTO    , :CDSERVORCA        ,
                    :NRITEMORCAMENTOPAI    , :NMITEMORCAMENTO   , :QTITEMORCAMENTO   ,
                    :CDTPMEDIDASERV        , :QTMEDIDAORCA      , :NRGRUPOFATURA     ,
                    :IDFATURAORCA          , :CDMODPGTO         , :QTPARCELASFATU    ,
                    :NRDIAVENCPARCELASFATU , :DTINICFATORC      , :VRUNITITEMORCA    ,
                    :VRUNITITEMORCALOCA    , :VRTOTALITEMORCA   , :TXFORMULAITORCA   ,
                    :IDTRANSPORTADORA      , :QTDIASCONTRATO    , :IDITEMOBRIGORCA   ,
                    :IDSOMASUBITENS        , :IDSOMANOITEMPAI   , :IDSOMANOTOTALORCA ,
                    :IDIMPRESSAOORCA       , :IDPRECOLOCACAO    , :NRORG             ,
                    :IDATIVO               , SYSDATE            , :NRORGINCLUSAO     ,
                    :CDOPERINCLUSAO        , :IDMULTMEDVRTOT    , :IDBLOQALTORC      ,
                    :IDADICITEMORC         , :IDADICCOBRITEMORC , :VRITEMSEMDESC     ,
                    :VRPERCDESCORCA        , :IDTPDESCORCA      , :NRTIPOORCAMENTO
                )";
            
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getDocumentosProposta(array $params) {
        $sql = "SELECT NRSEQORCADOC,
                       NMARQUIVO,
                       DSCAMINHOARQ,
                       DSTIPO,
                       VRTAMANHO 
                  FROM FCT_ORCAMENTODOC 
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG          = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function atualizarValorTotalProposta(array $params) {
        $sql = "UPDATE FCT_ORCAMENTO
                   SET VRORCAMENTO = (SELECT SUM(VRTOTITEMCOMDESC)
                                        FROM FCT_NEGOCIACAOPROPOSTA
                                       WHERE NRSEQORCAMENTO = FCT_ORCAMENTO.NRSEQORCAMENTO
                                         AND NRORG          = FCT_ORCAMENTO.NRORG)
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG          = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getNomeProduto(array $params) {
        $sql = "SELECT NMSERVORCA
                  FROM FCT_SERVICOORCA
                 WHERE IDTIPO         = 'E'
                   AND IDTIPOELEMENTO = 'P'
                   AND IDELEMENTO     = :IDELEMENTO
                   AND NRORG          = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function atualizarPropostaCancelamento(array $params) {
        $sql = "UPDATE FCT_ORCAMENTO
                   SET IDSITUACAOORCAMENTO = 'CANCELADO',
                       IDATIVO             = 'N',
                       DTULTATU            = SYSDATE,
                       CDOPERULTATU        = :CDOPERULTATU,
                       NRORGULTATU         = :NRORGULTATU
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG          = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function atualizarPropostaAceite(array $params) {
        $sql = "UPDATE FCT_ORCAMENTO
                   SET IDSITUACAOORCAMENTO = 'ACEITO',
                       DTACEITEORCA        = SYSDATE,
                       DTULTATU            = SYSDATE,
                       CDOPERULTATU        = :CDOPERULTATU,
                       NRORGULTATU         = :NRORGULTATU
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG          = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getSituacaoProposta(array $params) {
        $sql = "SELECT IDSITUACAOORCAMENTO
                  FROM FCT_ORCAMENTO
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG          = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Atualiza o documento anexado na proposta
     */
    public function atualizarDocumentoProposta(array $params) {
       $sql = "UPDATE FCT_ORCAMENTODOC
                  SET NMARQUIVO    = :NMARQUIVO,
                      DSCAMINHOARQ = :DSCAMINHOARQ,
                      VRTAMANHO    = :VRTAMANHO,
                      DSTIPO       = :DSTIPO,
                      DTULTATU     = SYSDATE,
                      CDOPERULTATU = :CDOPERULTATU,
                      NRORGULTATU  = :NRORGULTATU
                WHERE NRSEQORCADOC   = :NRSEQORCADOC
                  AND NRSEQORCAMENTO = :NRSEQORCAMENTO
                  AND NRORG          = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function getParametrosFaturamentoParaItensNegociacaoProposta($params, $escopos, $servicos) {
        $sql = "SELECT PFESC.NRTIPOORCAMENTO,
                       ITORC.NRITEMORCAMENTO,
                       ITORC.NRITEMORCAMENTOPAI,
                       ITORC.CDSERVORCA,
                       ITORC.VRTOTALITEMORCA,
                       NVL(PFIT.IDTPFATURA, PFESC.IDTPFATURA) AS IDTPFATURA,
                       NVL(PFIT.CDTIPOOPERFATURA, PFESC.CDTIPOOPERFATURA) AS CDTIPOOPERFATURA,
                       NVL(PFIT.CDSERIENF, PFESC.CDSERIENF) AS CDSERIENF,
                       NVL(PFIT.CDEMPRESA, PFESC.CDEMPRESA) AS CDEMPRESA,
                       NVL(PFIT.CDINSCESTA, PFESC.CDINSCESTA) AS CDINSCESTA,
                       NVL(PFIT.CDINSCMUNI, PFESC.CDINSCMUNI) AS CDINSCMUNI,
                       NVL(PFIT.CDPRODFATURA, NVL(PFESC.CDPRODFATURA, SERV.CDPRODFATSERV)) AS CDPRODFATURA,
                       NVL(PFIT.CDFILIALFATURA, PFESC.CDFILIALFATURA) AS CDFILIALFATURA,
                       NVL(PFIT.NRPARCFATURA, NVL(PFESC.NRPARCFATURA, ORC.NRPARCNEGOCIO)) AS NRPARCFATURA,
                       NVL(PFIT.QTPARCELASFATU, PFESC.QTPARCELASFATU) AS QTPARCELASFATU,
                       NVL(PFESC.QTPARCELASFATU, 1) AS QTPARCELASFATUESC,
                       NVL(PFIT.QTDIASAPURACAO, PFESC.QTDIASAPURACAO) AS QTDIASAPURACAO,
                       NVL(PFIT.NRDIACALCVENC, PFESC.NRDIACALCVENC) AS NRDIACALCVENC,
                       NVL(PFIT.QTDIASFATUVENC, PFESC.QTDIASFATUVENC) AS QTDIASFATUVENC,
                       NVL(PFIT.IDTPCALCVENC, PFESC.IDTPCALCVENC) AS IDTPCALCVENC,
                       NVL(PFIT.IDMESCALCVENC, PFESC.IDMESCALCVENC) AS IDMESCALCVENC,
                       NVL(ITESC.IDPREVCOBRFUT, 'N') AS IDPREVCOBRFUT
                  FROM FCT_CAPAPARAMFATESC PFESC
                  LEFT JOIN FCT_ITESCOPOPROPOSTA ITESC
                    ON PFESC.NRTIPOORCAMENTO = ITESC.NRTIPOORCAMENTO
                   AND PFESC.NRORG           = ITESC.NRORG
                   AND ITESC.CDSERVORCA      IN ($servicos)
                  LEFT JOIN FCT_PARAMFATITESC PFIT
                    ON ITESC.NRTIPOORCAMENTO    = PFIT.NRTIPOORCAMENTO
                   AND ITESC.NRITESCOPOPROPOSTA = PFIT.NRITESCOPOPROPOSTA
                   AND ITESC.NRORG              = PFIT.NRORG
                 INNER JOIN FCT_ORCAMENTO ORC
                    ON PFESC.NRORG        = ORC.NRORG
                   AND ORC.NRSEQORCAMENTO = :NRSEQORCAMENTO
                 INNER JOIN FCT_ITEMORCAMENTO ITORC
                    ON ORC.NRSEQORCAMENTO = ITORC.NRSEQORCAMENTO
                   AND ORC.NRORG          = ITORC.NRORG
                   AND ITORC.CDSERVORCA   IN ($servicos)
                  LEFT JOIN FCT_SERVICOORCA SERV
                    ON ITORC.CDSERVORCA = SERV.CDSERVORCA
                   AND ITORC.NRORG      = SERV.NRORG
                 WHERE PFESC.NRTIPOORCAMENTO IN ($escopos)
                   AND PFESC.NRORG           = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function inserirParcelaNegociacao(array $params) {
        $sql = "INSERT INTO FCT_PARCELANEGOPROP (
                    NRPARCELANEGOPROP, NRNEGOCIACAOPROPOSTA, QTDIASFATURAMENTO,
                    NRDIAVENCIMENTO,   VRPARCELA,            IDATIVO,
                    NRORG,             DTINCLUSAO,           NRORGINCLUSAO,
                    CDOPERINCLUSAO,    NRPARCELA
                )
                VALUES (
                    :NRPARCELANEGOPROP, :NRNEGOCIACAOPROPOSTA, :QTDIASFATURAMENTO,
                    :NRDIAVENCIMENTO,   :VRPARCELA,            :IDATIVO,
                    :NRORG,             SYSDATE,               :NRORGINCLUSAO,
                    :CDOPERINCLUSAO,    :NRPARCELA
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function getTipoMedidaPeloNome(array $params) {
        $sql = "SELECT CDTPMEDIDASERV
                  FROM FCT_TIPOMEDIDASERV
                 WHERE UPPER(DSTPMEDIDASERV) = UPPER(:DSTPMEDIDASERV)
                   AND NRORG                 = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getContratosLigadosAProposta(array $params) {
        $sql = "SELECT NRSEQCONTRATO, 
                       NRTIPOORCAMENTO,
                       IDGERADOPOR
                FROM FCT_REFEORCACONT
                WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                  AND NRORG          = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function alterarSituacaoContrato(array $params) {
        $sql = "UPDATE FCT_CONTRATO
                SET IDSITUACAOCONTRATO = 'A',
                    DTULTATU           = SYSDATE,
                    NRORGULTATU        = :NRORG,
                    CDOPERULTATU       = :CDOPERULTATU
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                  AND NRORG         = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirInfoAprovacao(array $params) {
        $sql = "INSERT INTO FCT_APROVACONTRATO (
                    NRSEQAPROVCONT, NRSEQCONTRATO,  DTAPROVCONTR,   IDAPROCCONTR,
                    NRORG,          DTINCLUSAO,     DTULTATU,       NRORGINCLUSAO,
                    CDOPERINCLUSAO, NRORGULTATU,    CDOPERULTATU,   IDATIVO
                ) VALUES (
                    :NRSEQAPROVCONT, :NRSEQCONTRATO,  SYSDATE,   :IDAPROCCONTR,
                    :NRORG,          SYSDATE,         NULL,      :NRORG,
                    :OPERADOR,       NULL,            NULL,      'S'
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getInfoSolicitacoesAguardadoProposta(array $params) {
        $sql = "SELECT SOL.CDFILIAL,
                       SOL.NRSOLISERV,
                       SOL.CDCLIENTE,
                       SOL.CDPRODGRUP,
                       SOL.DSREFESOLI,
                       SOL.CDSISTEMA,
                       SOL.CDINTECLIE,
                       SOL.CDFASETRAM,
                       SOL.VRDESCORCAM,
                       SOL.VRPEDESORCAM,
                       SOL.VRSOLIORCA,
                       SOL.DSOBSPROPSOL,
                       SOL.CDOPERRESP,
                       SOL.CDOPERSOLI,
                       ORC.NRSEQORCAMENTO,
                       (SELECT CDOPERADOR
                          FROM LOGFASETRAM
                         WHERE CDFILIAL     = SOL.CDFILIAL
                           AND NRSOLISERV   = SOL.NRSOLISERV
                           AND CDFASETRAM   = :CDFASETRAM
                           AND DTALFASETRAM = (SELECT MAX(DTALFASETRAM)
                                                 FROM LOGFASETRAM
                                                WHERE CDFILIAL   = SOL.CDFILIAL
                                                  AND NRSOLISERV = SOL.NRSOLISERV
                                                  AND CDFASETRAM = :CDFASETRAM)) AS CDOPERULTFASE
                  FROM SOLISERV SOL
                  LEFT JOIN FCT_ORCAMENTO ORC
                    ON SOL.NRSOLISERV          = ORC.NRSOLISERV
                   AND ORC.IDATIVO             = 'S'
                   AND ORC.IDSITUACAOORCAMENTO <> 'CANCELADO'
                 WHERE SOL.CDFASETRAM = :CDFASETRAM
                   AND SOL.NRORG      = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getDadosInterlocutor(array $params) {
        $sql = "SELECT DSEMAILOPER, NMOPERADOR
                  FROM OPERADOR 
                 WHERE CDOPERADOR = :CDOPERADOR
                   AND NRORG      = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getItensSolicitacao(array $params) {
        $sql = "SELECT NVL(ORC.QTITORCSOLIC, 0) AS quantity,
                       NVL(ORC.VRORCADOSOLI, 0) AS totalValue,
                       NVL(ORC.VRITORCACLIS, 0) AS unitaryValue,
                       (SELECT DSUNIDADE
                          FROM ITEMORCAPROD ITPROD
                          JOIN UNIDMEDIDA UNID
                            ON ITPROD.SGUNIDADE = UNID.SGUNIDADE
                         WHERE CDITORCAPROD = ORC.CDITORCAPROD) AS measurement,
                       ITEMSM.CDSERVORCA AS id
                  FROM ORCASOLICITA ORC
                  JOIN ITEMORCAPROD_FCT_ITEMORCAMENTO ITEMSM
                    ON ORC.CDITORCAPROD = ITEMSM.CDITORCAPROD
                   AND ORC.NRORG        = ITEMSM.NRORG
                 WHERE ORC.NRSOLISERV = :NRSOLISERV
                   AND ORC.CDFILIAL   = :CDFILIAL
                   AND ORC.NRORG      = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getFilialSolicitacao(array $params) {
        $sql = "SELECT CDFILIAL
                  FROM SOLISERV
                 WHERE NRSOLISERV = :NRSOLISERV
                   AND NRORG      = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    
    public function getParcelasSolicitacao(array $params) {
        $sql = "SELECT VRPARCSOLI as \"value\",
                       NRPARCSOLI as \"billingDays\"
                  FROM PARCSOLISERV
                 WHERE CDFILIAL     = :CDFILIAL 
                   AND NRSOLISERV   = :NRSOLISERV   
                   AND NRORG        = :NRORG
                 ORDER BY NRPARCSOLI";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getOcamentoSolicitacao(array $params) {
        $sql = "SELECT NRSEQORCAMENTO
                  FROM FCT_ORCAMENTO
                 WHERE NRSOLISERV          = :NRSOLISERV
                   AND NRORG               = :NRORG
                   AND IDATIVO             = 'S'
                   AND IDSITUACAOORCAMENTO <> 'CANCELADO'";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function alterarSituacaoSolicitacao(array $params) {
        $sql = "UPDATE SOLISERV
                   SET CDFASETRAM   = :CDFASETRAM
                 WHERE CDFILIAL     = :CDFILIAL 
                   AND NRSOLISERV   = :NRSOLISERV 
                   AND NRORG        = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function vincularSolicitacaoAProposta(array $params) {
        $sql = "UPDATE FCT_ORCAMENTO
                   SET NRSOLISERV     = :NRSOLISERV
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG          = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getNomeProdutoSolicitacao(array $params) {
        $sql = "SELECT NMPRODUTO AS NMSERVORCA
                  FROM PRODUTO
                 WHERE CDPRODUTO = :CDPRODUTO
                   AND NRORG     = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        $dataset = $ps->fetchAll();
        return count($dataset) > 0 ? $dataset[0]["NMSERVORCA"] : null;
    }
    
    public function getTxAcaoFaseTramitacao(array $params) {
        $sql = "SELECT TXACAOFATRAM
                  FROM FASETRAMDEST
                 WHERE CDFASETRAM   = :CDFASETRAM
                   AND CDFASTRAMDES = :CDFASTRAMDES";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        $dataset = $ps->fetchAll();
        return count($dataset) > 0 ? $dataset[0]["TXACAOFATRAM"] : null;
    }
    
    public function inserirLogAlteracaoFaseTram(array $params) {
        $sql = "INSERT INTO LOGFASETRAM (
                    CDFILIAL,      NRSOLISERV,    DTALFASETRAM,
                    CDFASETRAM,    CDOPERADOR,    DSALFASETRAM,
                    TXACAOLFTRAM,  CDOPERRESP,    IDATIVO,
                    NRORG,         DTINCLUSAO,    DTULTATU,
                    NRORGINCLUSAO, CDOPERINCLUSAO
                ) VALUES (
                    :CDFILIAL,      :NRSOLISERV,    SYSDATE,
                    :CDFASETRAM,    :CDOPERADOR,    :DSALFASETRAM,
                    :TXACAOLFTRAM,  :CDOPERRESP,    'S',
                    :NRORG,         SYSDATE,        NULL,
                    :NRORGINCLUSAO, :CDOPERINCLUSAO
                )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getQtParcCustCliente(array $params) {
        $sql = "SELECT QTPARCCUST
                  FROM CLIENTE
                 WHERE CDCLIENTE = :CDCLIENTE
                   AND NRORG     = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getDadosManutencaoCustomizacao(array $params) {
        $sql = "SELECT CDSERVORCA, NMSERVORCA, VRPERCMANUCUSTOM, NRESCOPOMANUCUSTOM
                  FROM FCT_SERVICOORCA
                 WHERE IDLICENUSOMANUT = 'M'
                   AND NRORG = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
}

?>